import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker, message, Upload } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import moment from 'moment';
import router from 'umi/router';
import apis from '../../../../services/apis';
import XForm, { FieldTypes } from '../../../../components/XForm';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
const { TextArea } = Input;

const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 14 },
};

function HouseAdd(props) {
  function checkValues() {
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log(values,"valuesvaluesvalues")
      }
    });
  }

  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('Received values of form: ', values);
        const { activityTime, signupTime } = values
        const [startDate, endDate] = activityTime
        values.startDate = moment(startDate).format('YYYY-MM-DD HH:mm');
        values.endDate = moment(endDate).format('YYYY-MM-DD HH:mm');
        if (signupTime) {
          const [enlistStart, enlistEnd] = signupTime
          values.enlistStart = moment(enlistStart).format('YYYY-MM-DD HH:mm');
          values.enlistEnd = moment(enlistEnd).format('YYYY-MM-DD HH:mm');
        }
        
        console.log('submit data --->', values)
        if (dynamicId) {
          values.dynamicId = dynamicId
          request({ ...apis.activity.update, data: values }).then(data => {
            message.info('保存成功')
            // router.go(-1)
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.add, data: { ...values } }).then((data) => {
            message.info('保存成功')
            router.push({
              pathname: '/activity/editActivity',
              query: {
                dynamicId: data.dynamicId,
              },
            });
            // router.go(-1)
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        }
      }
    });
  }

  function cancelPage(e) {
    
  }

  const { getFieldDecorator } = props.form;
  return (
    <>
      <Form {...formItemLayout} onSubmit={handleSubmit}>
        <Form.Item label="楼栋">
        {getFieldDecorator('blockName', {
          rules: [
            {
              required: true,
              message: '请输入楼栋',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="单元">
        {getFieldDecorator('unitName', {
          rules: [
            {
              required: true,
              message: '请输入单元',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="层">
        {getFieldDecorator('floorName', {
          rules: [
            {
              required: true,
              message: '请输入楼层',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="房号">
        {getFieldDecorator('roomName', {
          rules: [
            {
              required: true,
              message: '请输入房号',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="价格">
        {getFieldDecorator('price', {
          rules: [
            {
              required: true,
              message: '请输入价格',
            },
          ],
        })(<Input type="Number"/>)}
        </Form.Item>
        <Form.Item label="预选基础热度">
        {getFieldDecorator('heat', {
          rules: [
            {
              required: true,
              message: '请输入楼栋',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="户型">
        {getFieldDecorator('apartmentId', {
          rules: [
            {
              required: true,
              message: '请输入楼栋',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="发布状态">
        {getFieldDecorator('status', {
          rules: [
            {
              required: true,
              message: '请输入楼栋',
            },
          ],
        })(
          <Select placeholder="发布状态">
            <Option value="0">否</Option>
            <Option value="1">是</Option>
          </Select>,
        )}
        </Form.Item>
        <Form.Item wrapperCol={{ span: 12, offset: 8 }}>
          <Button type="primary" htmlType="submit">
            确认
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;
          <Button type="primary" onClick={() => checkValues()}>
            校验
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;
          <Button onClick={() => cancelPage({type: "house"})}>
            取消
          </Button>
        </Form.Item>
      </Form>
    </>
  )
}
const WrappedHouseAdd = Form.create({ name: 'house_add' })(HouseAdd);
export default WrappedHouseAdd
